@@ -449,7 +449,6 @@ gnome_print_context_new (GnomePrintConfig *config)
 
 	if (strcmp (drivername, "gnome-print-ps") == 0) {
 		GnomePrintContext *ps;
-		g_print ("Printing to Postscript...\n");
 		ps = gnome_print_ps2_new (config);
 		if (ps == NULL)
 			return NULL;
@@ -462,7 +461,6 @@ gnome_print_context_new (GnomePrintConfig *config)
 	}
 	
 	if (strcmp (drivername, "gnome-print-pdf") == 0) {
-		g_print ("Printing to PDF ...\n");
 		pc = gnome_print_pdf_new (config);
 		if (pc == NULL)
 			return NULL;
